<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversa</translation>
    </message>
    <message>
        <source>Cenzor</source>
        <translation>Censura</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Enable cenzor</source>
        <translation>Habilitar censura</translation>
    </message>
    <message>
        <source>Admonition</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swearwords</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exclusions</source>
        <translation>Exclusões</translation>
    </message>
    <message>
        <source>Message was cenzored</source>
        <translation>Mensagem foi censurada</translation>
    </message>
</context>
<context>
    <name>CenzorNotificationService</name>
    <message>
        <source>Cenzor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message was cenzored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your interlocutor used obscene word and became admonished</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ListEditWidget</name>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Mudar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
</context>
</TS>